---
name: 🚀 功能建议 (Chinese)
about: 为本项目提出新想法或改进建议
title: "[FEATURE] <功能名称>"
labels: enhancement
---

**你的需求是否与某个问题有关？**
请清晰描述，例如“当我在做...时，我感到很不方便”。

**描述你想要的解决方案**
描述你希望实现的功能。

**描述你考虑过的替代方案**
描述你考虑过的任何替代方案或绕过方法。

**其他背景**
在此处添加关于功能请求的任何其他背景、参考资料或截图。